/*
 * Copyright (C) 2009 Timothy Reaves
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */

#ifndef LOGBOOKCOMMON_HPP
#define LOGBOOKCOMMON_HPP

// these values are used as the names of SQL tables, and as map keys.
#define BARLOWS "barlows"
#define FILTERS "filters"
#define IMAGERS "imagers"
#define OBSERVATIONS "observations"
#define OBSERVERS "observers"
#define OCULARS "oculars"
#define OPTICS "optics"
#define OPTICS_TYPE "optics_type"
#define SESSIONS "sessions"
#define SITES "sites"
#define TARGETS "targets"
#define TARGET_TYPES "target_types"

#endif /*LOGBOOKCOMMON_HPP*/
